@@ -31,9 +31,9 @@ class MorseAccountUiPlugin : public AbstractAccountUiPlugin
 
 public:
     MorseAccountUiPlugin(QObject *parent, const QVariantList &);
-    virtual ~MorseAccountUiPlugin();
+    ~MorseAccountUiPlugin() override;
 
-    virtual AbstractAccountUi* accountUi(const QString &connectionManager, const QString &protocol, const QString &serviceName) override;
+    AbstractAccountUi* accountUi(const QString &connectionManager, const QString &protocol, const QString &serviceName) override;
 
 private:
     Q_DISABLE_COPY(MorseAccountUiPlugin)
