@@ -30,8 +30,8 @@ class SipeAdvancedOptionsWidget : public AbstractAccountParametersWidget
     Q_OBJECT
 
 public:
-    explicit SipeAdvancedOptionsWidget(ParameterEditModel *model, QWidget *parent = 0);
-    virtual ~SipeAdvancedOptionsWidget();
+    explicit SipeAdvancedOptionsWidget(ParameterEditModel *model, QWidget *parent = nullptr);
+    ~SipeAdvancedOptionsWidget() override;
 
 private:
     Q_DISABLE_COPY(SipeAdvancedOptionsWidget)
